/* -*-c-*-
 *
 * $Id: field-parse.c,v 1.1 2004/03/27 17:54:11 mdw Exp $
 *
 * Parse field descriptions
 *
 * (c) 2004 Straylight/Edgeware
 */

/*----- Licensing notice --------------------------------------------------* 
 *
 * This file is part of Catacomb.
 *
 * Catacomb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 * 
 * Catacomb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with Catacomb; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 */

/*----- Revision history --------------------------------------------------* 
 *
 * $Log: field-parse.c,v $
 * Revision 1.1  2004/03/27 17:54:11  mdw
 * Standard curves and curve checking.
 *
 */

/*----- Header files ------------------------------------------------------*/

#include "field.h"

/*----- Main code ---------------------------------------------------------*/

/* --- @field_parse@ --- *
 *
 * Arguments:	@qd_parse *qd@ = parser context
 *
 * Returns:	Field pointer if OK, or null.
 *
 * Use:		Parses a field description, which has the form
 *
 *		  * `prime', `niceprime' or `binpoly'
 *		  * an optional `:'
 *		  * the field modulus
 */

field *field_parse(qd_parse *qd)
{
  field *f;
  mp *m = MP_NEW;

  switch (qd_enum(qd, "prime,niceprime,binpoly")) {
    case 0:
      qd_delim(qd, ':');
      if ((m = qd_getmp(qd)) == 0) return (0);
      f = field_prime(m);
      break;
    case 1:
      qd_delim(qd, ':');
      if ((m = qd_getmp(qd)) == 0) return (0);
      f = field_niceprime(m);
      break;
    case 2:
      qd_delim(qd, ':');
      if ((m = qd_getmp(qd)) == 0) return (0);
      f = field_binpoly(m);
      break;
    default:
      f = 0;
      break;
  }
  mp_drop(m);
  return (f);
}

/*----- That's all, folks -------------------------------------------------*/
